@@ -68,7 +68,7 @@ class Client(BaseClient, AbstractClient):
 
         if symbol is not None:
             data = self._pick(result.get('result').get('symbols'), symbol)
-            result['result'] = data
+            result['result']['symbols'] = data
 
         return result
 
@@ -159,22 +159,34 @@ class Client(BaseClient, AbstractClient):
         return self._post('account/orders', signed=True, json=self._get_kwargs(locals(), del_nones=True))
 
     def order_market(self, symbol: str, side: str, quantity: float, client_id: str = None) -> t.Dict:
-        return self.create_order(symbol, side, self.ORDER_TYPE_MARKET, quantity, client_id)
+        return self.create_order(
+            symbol=symbol, side=side, type=self.ORDER_TYPE_MARKET, quantity=quantity, client_id=client_id
+        )
 
     def order_limit(self, symbol: str, side: str, quantity: float, price: float, client_id: str = None) -> t.Dict:
-        return self.create_order(symbol, side, self.ORDER_TYPE_LIMIT_MAKER, quantity, client_id)
+        return self.create_order(
+            symbol=symbol, side=side, type=self.ORDER_TYPE_LIMIT, quantity=quantity, client_id=client_id, price=price
+        )
 
     def order_market_buy(self, symbol: str, quantity: float, client_id: str = None) -> t.Dict:
-        return self.order_market(symbol, self.SIDE_BUY, quantity, client_id)
+        return self.order_market(
+            symbol=symbol, side=self.SIDE_BUY, quantity=quantity, client_id=client_id
+        )
 
     def order_market_sell(self, symbol: str, quantity: float, client_id: str = None) -> t.Dict:
-        return self.order_market(symbol, self.SIDE_SELL, quantity, client_id)
+        return self.order_market(
+            symbol=symbol, side=self.SIDE_SELL, quantity=quantity, client_id=client_id
+        )
 
     def order_limit_buy(self, symbol: str, quantity: float, price: float, client_id: str = None) -> t.Dict:
-        return self.order_limit(symbol, self.SIDE_BUY, quantity, price, client_id)
+        return self.order_limit(
+            symbol=symbol, side=self.SIDE_BUY, quantity=quantity, price=price, client_id=client_id
+        )
 
     def order_limit_sell(self, symbol: str, quantity: float, price: float, client_id: str = None) -> t.Dict:
-        return self.order_limit(symbol, self.SIDE_SELL, quantity, price, client_id)
+        return self.order_limit(
+            symbol=symbol, side=self.SIDE_SELL, quantity=quantity, price=price, client_id=client_id
+        )
 
     def cancel_order(self, order_id: str) -> t.Dict:
         return self._delete(f'account/orders', signed=True, json={'clientOrderId': order_id})
@@ -184,11 +196,11 @@ class Client(BaseClient, AbstractClient):
 
         if symbol is not None:
             data = self._pick(result.get('result').get('orders'), "symbol", symbol)
-            result['result'] = data
+            result['result']['orders'] = data
 
         if side is not None:
             data = self._pick(result.get('result').get('orders'), "side", side)
-            result['result'] = data
+            result['result']['orders'] = data
 
         return result
 
@@ -290,7 +302,7 @@ class AsyncClient(BaseClient, AbstractClient):
 
         if symbol is not None:
             data = self._pick(result.get('result').get('symbols'), symbol)
-            result['result'] = data
+            result['result']['symbols'] = data
 
         return result
 
@@ -380,29 +392,37 @@ class AsyncClient(BaseClient, AbstractClient):
     async def create_order(
             self, symbol: str, side: str, type: str, quantity: float, price: float = None, client_id: str = None
     ) -> t.Dict:
-        return await self._post('account/orders', signed=True, json=self._get_kwargs(locals()))
+        return await self._post('account/orders', signed=True, json=self._get_kwargs(locals(), del_nones=True))
 
     async def order_market(self, symbol: str, side: str, quantity: float, client_id: str = None) -> t.Dict:
-        params = self._get_kwargs(locals())
-        params.update({'type': self.ORDER_TYPE_MARKET})
-        return await self._post('account/orders', signed=True, json=params)
+        return await self.create_order(
+            symbol=symbol, side=side, type=self.ORDER_TYPE_MARKET, quantity=quantity, client_id=client_id
+        )
 
     async def order_limit(self, symbol: str, side: str, quantity: float, price: float, client_id: str = None) -> t.Dict:
-        params = self._get_kwargs(locals())
-        params.update({'type': self.ORDER_TYPE_LIMIT})
-        return await self._post('account/orders', signed=True, json=params)
+        return await self.create_order(
+            symbol=symbol, side=side, type=self.ORDER_TYPE_LIMIT, quantity=quantity, client_id=client_id, price=price
+        )
 
     async def order_market_buy(self, symbol: str, quantity: float, client_id: str = None) -> t.Dict:
-        return await self.order_market(symbol, self.SIDE_BUY, quantity, client_id)
+        return await self.order_market(
+            symbol=symbol, side=self.SIDE_BUY, quantity=quantity, client_id=client_id
+        )
 
     async def order_market_sell(self, symbol: str, quantity: float, client_id: str = None) -> t.Dict:
-        return await self.order_market(symbol, self.SIDE_SELL, quantity, client_id)
+        return await self.order_market(
+            symbol=symbol, side=self.SIDE_SELL, quantity=quantity, client_id=client_id
+        )
 
     async def order_limit_buy(self, symbol: str, quantity: float, price: float, client_id: str = None) -> t.Dict:
-        return await self.order_limit(symbol, self.SIDE_BUY, quantity, price, client_id)
+        return await self.order_limit(
+            symbol=symbol, side=self.SIDE_BUY, quantity=quantity, price=price, client_id=client_id
+        )
 
     async def order_limit_sell(self, symbol: str, quantity: float, price: float, client_id: str = None) -> t.Dict:
-        return await self.order_limit(symbol, self.SIDE_SELL, quantity, price, client_id)
+        return await self.order_limit(
+            symbol=symbol, side=self.SIDE_SELL, quantity=quantity, price=price, client_id=client_id
+        )
 
     async def cancel_order(self, order_id: str) -> t.Dict:
         return await self._delete(f'account/orders', signed=True, json={'clientOrderId': order_id})
@@ -412,11 +432,11 @@ class AsyncClient(BaseClient, AbstractClient):
 
         if symbol is not None:
             data = self._pick(result.get('result').get('orders'), "symbol", symbol)
-            result['result'] = data
+            result['result']['orders'] = data
 
         if side is not None:
             data = self._pick(result.get('result').get('orders'), "side", side)
-            result['result'] = data
+            result['result']['orders'] = data
 
         return result
 
